Contributing to Connexion/TODOs
===============================

We welcome your ideas, issues, and pull requests. Just follow the usual/standard GitHub practices.

TODOs
-----

If you'd like to become a more consistent contributor to Connexion, we'd love your help working on 
these we have a list of `issues where we are looking for contributions`_.

.. _issues where we are looking for contributions: https://github.com/zalando/connexion/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22
